/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.taglib.chart.model;

import java.util.Collection;
import java.util.List;

/**
 * @author Julien Castelain
 */
public class MixedDataColumn extends Column {

	/**
	 * Creates a new mixed data column.
	 *
	 * @param id the column's ID
	 * @param values the column's values. Each value can be an instance, array,
	 *        or {@link Collection} of {@link Number}s.
	 */
	public MixedDataColumn(String id, Collection<?> values) {
		super(id);

		addValues(values);
	}

	/**
	 * Creates a new mixed data column.
	 *
	 * @param id the column's ID
	 * @param values the column's values. Each value can be an instance or array
	 *        of {@link Number}s.
	 */
	public MixedDataColumn(String id, Object... values) {
		super(id);

		addValues(values);
	}

	/**
	 * Adds a value to the column.
	 *
	 * @param value an array of {@link Number}s for the column values
	 */
	public void addValue(Object value) {
		List<Object> data = getData();

		Class<?> clazz = value.getClass();

		if (value instanceof Number) {
			data.add(value);
		}
		else if (value instanceof Collection) {
			Collection<?> collection = (Collection<?>)value;

			data.add(collection.toArray());
		}
		else if (clazz.isArray()) {
			data.add(value);
		}
		else {
			throw new IllegalArgumentException(
				"Value can only be an instance, array, or collection of " +
					"numbers");
		}
	}

	/**
	 * Adds one or several values to the column.
	 *
	 * @param values the {@link Number}s for the column values
	 */
	public void addValues(Collection<?> values) {
		for (Object value : values) {
			addValue(value);
		}
	}

	/**
	 * Adds one or several values to the column.
	 *
	 * @param values an array of {@link Number}s for the column values
	 */
	public void addValues(Object... values) {
		for (Object value : values) {
			addValue(value);
		}
	}

}